SerEnum
=======

.. currentmodule:: wwt_data_formats.enums

.. autoclass:: SerEnum
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SerEnum.from_text

   .. rubric:: Methods Documentation

   .. automethod:: from_text
